@@ -129,8 +129,8 @@ public class MailsEndpoint {
     @Consumes(MediaType.APPLICATION_JSON)
     @Produces(MediaType.APPLICATION_JSON)
     public Response getStubs(@Context HttpServletRequest request, String rawRequestBody) {
-        log.info("Retrieving stubs");
         SessionData sessionData = RequestUtil.getSessionData(request);
+        log.error("Retrieving stubs");
         MailsRequestBody requestBody = JacksonUtil.parse(rawRequestBody, MailsRequestBody.class);
         RequestUtil.checkParam(FIELD_FOLDER_ID, requestBody.getFolderId());
         boolean threaded = RequestUtil.getBooleanParameter(requestBody.getThreaded(), true);
@@ -145,8 +145,8 @@ public class MailsEndpoint {
     @Consumes(MediaType.APPLICATION_JSON)
     @Produces(MediaType.APPLICATION_JSON)
     public Response getNewStubs(@Context HttpServletRequest request, String rawRequestBody) {
-        log.info("Retrieving new stubs");
         SessionData sessionData = RequestUtil.getSessionData(request);
+        log.info("Retrieving new stubs");
         NewMailsRequestBody requestBody = JacksonUtil.parse(rawRequestBody, NewMailsRequestBody.class);
         RequestUtil.checkParam(FIELD_FOLDER_ID, requestBody.getFolderId());
         RequestUtil.checkParam(FIELD_LAST_RECEIVED_DATE, requestBody.getLastReceivedDate());
@@ -162,8 +162,8 @@ public class MailsEndpoint {
     @Consumes(MediaType.APPLICATION_JSON)
     @Produces(MediaType.APPLICATION_JSON)
     public Response getEnvelopes(@Context HttpServletRequest request, String rawRequestBody) {
-        log.info("Retrieving envelopes");
         SessionData sessionData = RequestUtil.getSessionData(request);
+        log.info("Retrieving envelopes");
         MailsRequestBody requestBody = JacksonUtil.parse(rawRequestBody, MailsRequestBody.class);
         RequestUtil.checkParam(FIELD_FOLDER_ID, requestBody.getFolderId());
         RequestUtil.checkParam(FIELD_MAIL_IDS, requestBody.getMailIds());
@@ -178,8 +178,8 @@ public class MailsEndpoint {
     @Consumes(MediaType.APPLICATION_JSON)
     @Produces(MediaType.APPLICATION_JSON)
     public Response getNewEnvelopes(@Context HttpServletRequest request, String rawRequestBody) {
-        log.info("Retrieving new stubs");
         SessionData sessionData = RequestUtil.getSessionData(request);
+        log.info("Retrieving new stubs");
         NewMailsRequestBody requestBody = JacksonUtil.parse(rawRequestBody, NewMailsRequestBody.class);
         RequestUtil.checkParam(FIELD_FOLDER_ID, requestBody.getFolderId());
         RequestUtil.checkParam(FIELD_LAST_RECEIVED_DATE, requestBody.getLastReceivedDate());
@@ -194,8 +194,8 @@ public class MailsEndpoint {
     @Consumes(MediaType.APPLICATION_JSON)
     @Produces(MediaType.APPLICATION_JSON)
     public Response getMail(@Context HttpServletRequest request, String rawRequestBody) {
-        log.info("Retrieving a complete mail");
         SessionData sessionData = RequestUtil.getSessionData(request);
+        log.info("Retrieving a complete mail");
         MailsRequestBody requestBody = JacksonUtil.parse(rawRequestBody, MailsRequestBody.class);
         String folderId = requestBody.getFolderId();
         RequestUtil.checkParam(FIELD_FOLDER_ID, folderId);
@@ -212,8 +212,8 @@ public class MailsEndpoint {
     @Path("/delete")
     @Consumes(MediaType.APPLICATION_JSON)
     public Response deleteMails(@Context HttpServletRequest request, String rawRequestBody) {
-        log.info("Deleting mails");
         SessionData sessionData = RequestUtil.getSessionData(request);
+        log.info("Deleting mails");
         MailsDeleteRequestBody requestBody = JacksonUtil.parse(rawRequestBody, MailsDeleteRequestBody.class);
         RequestUtil.checkParam(FIELD_FOLDER_ID, requestBody.getFolderId());
         RequestUtil.checkParam(FIELD_MAIL_IDS, requestBody.getMailIds());
@@ -226,8 +226,8 @@ public class MailsEndpoint {
     @Path("/move")
     @Consumes(MediaType.APPLICATION_JSON)
     public Response moveMails(@Context HttpServletRequest request, String rawRequestBody) {
-        log.info("Moving mails");
         SessionData sessionData = RequestUtil.getSessionData(request);
+        log.info("Moving mails");
         MoveMailsRequestBody requestBody = JacksonUtil.parse(rawRequestBody, MoveMailsRequestBody.class);
         RequestUtil.checkParam(FIELD_FOLDER_ID, requestBody.getFolderId());
         RequestUtil.checkParam(FIELD_MAIL_IDS, requestBody.getMailIds());
@@ -329,6 +329,7 @@ public class MailsEndpoint {
 
     private Response setFlags(HttpServletRequest request, String rawRequestBody, MailFlags flags) {
         SessionData sessionData = RequestUtil.getSessionData(request);
+        log.info("Setting flags");
         SetFlagsRequestBody requestBody = JacksonUtil.parse(rawRequestBody, SetFlagsRequestBody.class);
         RequestUtil.checkParam(FIELD_FOLDER_ID, requestBody.getFolderId());
         RequestUtil.checkParam(FIELD_MAIL_IDS, requestBody.getMailIds());
@@ -428,6 +429,7 @@ public class MailsEndpoint {
 
     private Response clearFlags(HttpServletRequest request, String rawRequestBody, MailFlags flags) {
         SessionData sessionData = RequestUtil.getSessionData(request);
+        log.info("Clearing flags");
         SetFlagsRequestBody requestBody = JacksonUtil.parse(rawRequestBody, SetFlagsRequestBody.class);
         RequestUtil.checkParam(FIELD_FOLDER_ID, requestBody.getFolderId());
         RequestUtil.checkParam(FIELD_MAIL_IDS, requestBody.getMailIds());
@@ -439,8 +441,8 @@ public class MailsEndpoint {
     @Path("/color")
     @Consumes(MediaType.APPLICATION_JSON)
     public Response setColor(@Context HttpServletRequest request, String rawRequestBody) {
-        log.info("Set colors");
         SessionData sessionData = RequestUtil.getSessionData(request);
+        log.info("Set colors");
         SetColorsRequestBody requestBody = JacksonUtil.parse(rawRequestBody, SetColorsRequestBody.class);
         RequestUtil.checkParam(FIELD_FOLDER_ID, requestBody.getFolderId());
         RequestUtil.checkParam(FIELD_MAIL_IDS, requestBody.getMailIds());
